@@ -39,9 +39,6 @@ struct Node<T> {
     value: Option<T>,
 }
 
-unsafe impl<T: Send + 'static> Send for Node<T> {}
-unsafe impl<T: Sync> Sync for Node<T> {}
-
 struct State<T> {
     _pad0: [u8; 64],
     buffer: Vec<UnsafeCell<Node<T>>>,
